import { ComponentPropsWithoutRef } from 'react';
import { ColumnDef, createColumnHelper, SortingState, RowSelectionState, RowSelectionOptions, Row } from '@tanstack/react-table';
import { Table as UiTable } from '../ui/table';
interface PaginationState {
    total?: number;
    page: number;
    pageSize: number;
}
export type { ColumnDef };
export { createColumnHelper };
export interface TableProps<TData> extends ComponentPropsWithoutRef<typeof UiTable> {
    columns: ColumnDef<TData, any>[];
    data: TData[];
    loading?: boolean;
    bordered?: boolean;
    defaultPagination?: Partial<PaginationState>;
    pagination?: PaginationState | false;
    autoPagination?: boolean;
    defaultSorting?: SortingState;
    sorting?: SortingState;
    autoSorting?: boolean;
    enableRowSelection?: RowSelectionOptions<TData>['enableRowSelection'];
    /**
     * @default 'multiple'
     */
    rowSelectionMode?: 'single' | 'multiple';
    defaultRowSelection?: RowSelectionState;
    rowSelection?: RowSelectionState;
    empty?: React.ReactNode;
    getRowId?: (originalRow: TData, index: number, parent?: Row<TData>) => string;
    onPaginationChange?: (pagination: PaginationState) => any;
    onSortingChange?: (sorting: SortingState) => any;
    onRowSelectionChange?: (rowSelection: RowSelectionState) => any;
    onRowClick?: (ev: React.MouseEvent<HTMLTableRowElement>, row: Row<TData>) => any;
}
export declare function Table<TData>(props: TableProps<TData>): import("react/jsx-runtime").JSX.Element;
